﻿using System;
using System.Linq;
using System.Text.RegularExpressions;

namespace FSNCleaner.Silverlight
{
    /// <summary>
    /// Regroupement des fonctions d'expression régulière.
    /// </summary>
    public static class FctRegex
    {
        /// <summary>
        /// Efface toutes les lignes de script.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseScript(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, @"@.*\n", string.Empty);
        }

        /// <summary>
        /// Efface toutes les lignes de doublage.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseSay(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, @"@say.*\n", string.Empty);
        }

        /// <summary>
        /// Efface toutes les lignes de commentaire.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseComment(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, @";.*\n", string.Empty);
        }

        /// <summary>
        /// Efface toutes les balises '[l][r]'.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseLR(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, "[[]l[]][[]r[]]", string.Empty);
        }

        /// <summary>
        /// Efface une couche de balises de Wrap.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseWrap(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, "[[]wrap text=\".*?\"[]]", string.Empty);
        }

        /// <summary>
        /// Efface toutes les balises '[r]'.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseSlashR(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, "[\r]", string.Empty);
        }

        /// <summary>
        /// Remplace les doubles quotes par des guillemets.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void ReplaceDoubleQuote(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, " \"", " « ");
            MyFile.TextString = Regex.Replace(MyFile.TextString, "\"", " »");
        }

        /// <summary>
        /// Remplace une balise type LineX par des tirets.
        /// </summary>
        /// <param name="line">Ligne à traiter.</param>
        /// <param name="regex">Expression régulière définissant la balise.</param>
        /// <param name="dash">Chaine de caractères contenant les tirets.</param>
        /// <returns>Ligne avec la balise word-wrapper.</returns>
        public static string ReplaceLineX(string line, string regex, string dash)
        {
            //On cherche toute les balises du type donnée
            MatchCollection ReplaceMatches = Regex.Matches(line, regex);

            //On efface la dernière balise trouvé
            line = line.Remove(ReplaceMatches[ReplaceMatches.Count - 1].Index,
                ReplaceMatches[ReplaceMatches.Count - 1].Length);
            //On insert les X tirets crée auparavant à la place
            line = line.Insert(ReplaceMatches[ReplaceMatches.Count - 1].Index, dash);

            return line;
        }

        /// <summary>
        /// Compte le nombre de page d'un Fichier.
        /// </summary>
        /// <param name="MyFile">Fichier à traiter.</param>
        /// <returns>Nombre de pages du Fichier.</returns>
        public static Int32 CountPage(Fichier MyFile)
        {
            MatchCollection MyMatchCollection = Regex.Matches(MyFile.TextString, "[*]page");

            return MyMatchCollection.Count;
        }

        /// <summary>
        /// Efface toutes les lignes 'pageX'.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void ErasePage(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, @"[*].*\n", string.Empty);
        }

        /// <summary>
        /// Efface les balises '[lineX]'.
        /// </summary>
        /// <param name="MyFile">Fichier à nettoyer.</param>
        public static void EraseLineX(Fichier MyFile)
        {
            MyFile.TextString = Regex.Replace(MyFile.TextString, @"[[]line.*[]]", string.Empty);
        }

        /// <summary>
        /// Compte le nombre de mot de la liste de lignes d'un Fichier.
        /// </summary>
        /// <param name="MyFile">Fichier à traiter.</param>
        /// <returns>Nombre de pages du Fichiers.</returns>
        public static Int32 CountWord(Fichier MyFile)
        {
            Regex myRegex = new Regex(@"\w");

            int nbWords = (from line in MyFile.Lines
                           from word in line.Split(null)
                           where myRegex.IsMatch(word)
                           select word).Count();

            return nbWords;
        }
    }
}