﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Text;

namespace FSNCleaner.Silverlight
{
    /// <summary>
    /// Gère un fichier Kirikiri Script et son contenu.
    /// </summary>
    public class Fichier : INotifyPropertyChanged
    {
        #region Declaration
        //Alors ci dessous vous pouvez admirer un superbe NotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        private String textString;
        public String TextString
        {
            get
            {
                return textString;
            }
            set
            {
                if (value != this.textString)
                {
                    this.textString = value;
                    NotifyPropertyChanged("TextString");
                }
            }
        }

        private String nameFile;
        public String NameFile
        {
            get
            {
                return nameFile;
            }
            set
            {
                if (value != this.nameFile)
                {
                    this.nameFile = value;
                    NotifyPropertyChanged("NameFile");
                }
            }
        }

        public List<string> Lines { get; set; }
        public Exception MyException { get; set; }
        #endregion

        /// <summary>
        /// Constructeur pour lire un fichier Kirikiri Script.
        /// </summary>
        /// <param name="file">StreamReader du fichier à lire.</param>
        public Fichier(StreamReader file)
        {
            StreamReader sr = file;

            //On lit tout le fichier
            TextString = sr.ReadToEnd();

            //On libère le fichier quand même !
            file.Dispose();
        }

        /// <summary>
        /// Sauvegarde le contenu d'un Fichier.
        /// </summary>
        /// <param name="fileName">Nom complet du fichier où sauvegarder.</param>
        /// <returns></returns>
        public void Save(string fileName)
        {
            //On verifie que le chemin existe
            if (!Directory.Exists(fileName))
            {
                Directory.CreateDirectory(Path.GetDirectoryName(fileName));
            }

            //On initialise un FileStream avec les options qu'on désire
            //L'emploie du "using" va désallouer le FileStream après usage
            using (FileStream fs = new FileStream(fileName, FileMode.Create, FileAccess.Write, FileShare.None))
            {
                //On utilise un StreamWriter pour sauvegarder le fichier
                //L'emploie du "using" va désallouer le StreamWriter après usage
                //On utilise l'encodage "Unicode"
                using (StreamWriter sw = new StreamWriter(fs, System.Text.Encoding.Unicode))
                {
                    sw.Write(TextString);
                }
            }
        }

        /// <summary>
        /// Efface tous les scripts, balises et commentaires du Fichier.
        /// </summary>
        public void Clean()
        {
            FctRegex.EraseScript(this);
            FctRegex.EraseLR(this);
            FctRegex.EraseWrap(this);
            FctRegex.EraseComment(this);
        }

        /// <summary>
        /// Transforme la chaine de texte d'un Fichier en la liste de lignes.
        /// </summary>
        public void MakeList()
        {
            Lines = new List<string>();
            FctRegex.EraseSlashR(this);
            Lines.AddRange(TextString.Split('\n'));
        }

        /// <summary>
        /// Transforme la liste de lignes en la chaine de texte.
        /// </summary>
        public void MakeString()
        {
            StringBuilder constructString = new StringBuilder();
            foreach (string line in Lines)
            {
                constructString.AppendLine(line);
            }
            TextString = constructString.ToString();
        }
    }
}